more_widgets library
Classes
- BottomActionSheet
- BottomActionSheetAction
- Represents an action shown in a bottom action sheet.
- Dialogs
- Utility class that provides platform-adaptive dialogs.
- GradientBackground
- A widget that paints a LinearGradient background and shows child on top.
- GradientButton
- A button with a gradient background that adapts to light/dark themes.
- LoadingWidget
- RoundedContainer
- A simple rounded container with configurable padding, margin and color.
Enums
- DefaultAction
- Describes which action is the default in a two-button dialog.
- DestructiveAction
- Describes which action is destructive in a two-button dialog.